@@ -8,7 +8,7 @@ import pandas as pd
 import datetime
 from os.path import join, split, exists
 from d3m_interface.basic_ta3 import BasicTA3
-from d3m_interface.visualization import plot_metadata
+from d3m_interface.visualization import plot_metadata, plot_comparison_pipelines
 from d3m_interface.data_converter import is_d3m_format, convert_d3m_format
 from d3m.metadata.problem import PerformanceMetric
 from threading import Thread
@@ -295,7 +295,7 @@ class Automl:
 
         return metric, score
 
-    def create_profiler_inputs(self, test_dataset=None):
+    def create_pipelineprofiler_inputs(self, test_dataset=None):
         """Create an proper input supported by PipelineProfiler based on the pipelines generated by a TA2 system
 
         :param test_dataset: Path to dataset. If None it will use the search scores, otherwise will score the
@@ -421,6 +421,27 @@ class Automl:
 
         return ', '.join(primitives_summary)
 
+    def plot_summary_dataset(self, dataset_path):
+        """ Plot histograms of the dataset
+
+        :param dataset_path: Path to dataset.  It supports D3M dataset, and CSV file
+        """
+        suffix = dataset_path.split('/')[-1]
+
+        if is_d3m_format(dataset_path, suffix):
+            dataset_path = join(dataset_path, 'dataset_%s/tables/learningData.csv' % suffix)
+
+        plot_metadata(dataset_path)
+
+    def plot_comparison_pipelines(self, test_dataset=None):
+        """ Plot PipelineProfiler visualization
+
+        :param test_dataset: Path to dataset. If None it will use the search scores, otherwise will score the
+            pipelines over the passed dataset
+        """
+        pipelineprofiler_inputs = self.create_pipelineprofiler_inputs(test_dataset)
+        plot_comparison_pipelines(pipelineprofiler_inputs)
+
     @staticmethod
     def add_new_ta2(ta2_id, docker_image_url):
         """Add a new TA2 system that is not already defined in the D3M Interface. It can also be a different version of
@@ -432,15 +453,3 @@ class Automl:
         TA2_DOCKER_IMAGES[ta2_id] = docker_image_url
         logger.info('%s TA2 added!', ta2_id)
 
-    @staticmethod
-    def plot_summary_dataset(dataset_path):
-        """ Plot histograms of the dataset
-
-        :param dataset_path: Path to dataset.  It supports D3M dataset, and CSV file
-        """
-        suffix = dataset_path.split('/')[-1]
-
-        if is_d3m_format(dataset_path, suffix):
-            dataset_path = join(dataset_path, 'dataset_%s/tables/learningData.csv' % suffix)
-
-        plot_metadata(dataset_path)
